
/*
 *
 *    Copyright 2010 Sun Microsystems, Inc. All rights reserved
 *
 *    Use is subject to license terms.
 *
 */

public class NonDeterministic implements Runnable {
    
    static {
        System.out.println("\n--------------- Running NonDeterministic Program ---------------");
        System.out.println("   Note:\n    All time measurements are expressed in microsecond units,");
        System.out.println("    unless otherwise indicated, for example ms (milliseconds) and ns (nanoseconds).\n");


        // Forces a load and initialization of Fibonacci classes
        Fibonacci1 f1 = new Fibonacci1(10);
        Fibonacci2 f2 = new Fibonacci2(10);
        f1.computeFib();
        f2.computeFib();
        
        // Forces a load and initialization of GarbageProducer classes
        GarbageProducer1 gp1 = new GarbageProducer1(10);
        GarbageProducer2 gp2 = new GarbageProducer2(10);
        gp1.produceGarbage(10);
        gp2.produceGarbage(10);

        // Forces a load and initialization of plugged in code
        // to preload and preinitialize your own stressing code.
        // Replace Fibonacci1 by the name of your own StressingObject class
        // And uncomment the next 3 lines
        // NonDeterministic tmpNonDeterministic = new NonDeterministic(false, 1, 1);
        // tmpNonDeterministic.setVerbosity(false);
        // tmpNonDeterministic.stress("Fibonacci1", 10, 10);

        System.out.println("   Static initialization finished: ");
        System.out.println("     ==> Fibonacci classes initialized and loaded");
    }
    
    // Stressing Iteration data ( captured as program parameters)
    int nb_outer_iterations = 0;
    int nb_inner_iterations = 0;
    int nb_stress_class_iterations = 0;
    int pause_time = 0;

    // stressing Allocation data ( captured as program parameters )
    int allocation_array_size = 0;
    boolean garbage_producer = false;

    // Verbosity flag (captured as program parameter)
    static boolean verbosity = false;

    // stress java.lang.Thread priority
    int thread_priority;

    // timestamps array for bench thread
    long[] wallclock_times_begin_loops = null; 
    long[] wallclock_times_end_loops = null; 

    // measurements instance
    Measurements measurements = null;
    
    // wether or not time measurements should be recorded or not 
    boolean records_time_measures;

     

    // delegates result printing to measurement
    private void outputResults() {
        measurements.computeAndPrintStatResults(wallclock_times_begin_loops, wallclock_times_end_loops, null);
    }

    /** Instantiate a StressingObject from stressingObjectClassName and
        and stresses nb_inner_iterations times with this stressingObject
        which is supposed to iterate nb_stress_class_iterations times by itself */
    void stress(String stressingObjectClassName, int nb_inner_iterations, int nb_stress_class_iterations) {
        StressingObject so = null;
        
        try {
            so = (StressingObject) (Class.forName(stressingObjectClassName).newInstance());
            so.setStressClassIterations(nb_stress_class_iterations);
            for (int i = 1; i <= nb_inner_iterations; i++) {
                so.stress();
            }
        }
        catch(Exception e) {System.out.println(e);}
    }


    // Fibonacci computation stress method
    // computes 2 fibonacci sequences "nb_outer_fib_iterations" times
    //  -  fib_number_to_calculate : quantity of fib numbers to compute
    void computeFibs(int nb_inner_iterations, int nb_stress_class_iterations) {
        Fibonacci1 f1 = new Fibonacci1(nb_stress_class_iterations);
        Fibonacci2 f2 = new Fibonacci2(nb_stress_class_iterations);
        
        for (int i = 1; i <= nb_inner_iterations; i++) {
            f1.computeFib();
            f2.computeFib();
        }
    }

    // Memory allocation stress method
    // 2 garbage production sequences "nb_inner_iterations" times
    //  - nb_stress_class_iterations : number of int arrays to allocate
    //  - allocation_array_size: size of the arrays to allocate
    void produceGarbage(int nb_inner_iterations, int nb_stress_class_iterations, int allocation_array_size) {

        GarbageProducer1 gp1 = new GarbageProducer1(allocation_array_size);
        GarbageProducer2 gp2 = new GarbageProducer2(allocation_array_size);
        
        for (int i = 1; i <= nb_inner_iterations; i++) {
            gp1.produceGarbage(nb_stress_class_iterations);
            gp2.produceGarbage(nb_stress_class_iterations);
        }
    }

    /** Creates a new instance of NonDeterministic */
    NonDeterministic(boolean records_time, int alloc_array_size, int nb_loops) {
        
        records_time_measures = records_time;

        if (records_time_measures) {
            wallclock_times_begin_loops = new long[nb_loops];
            wallclock_times_end_loops = new long[nb_loops];
        }

        if (alloc_array_size != 0) {
            garbage_producer = true;
            allocation_array_size = alloc_array_size;
        }

        measurements = new Measurements(nb_loops);
    }
    
    /** Changes verbosity level */
    private void setVerbosity(boolean verbose_flag) {
        verbosity = verbose_flag;
        measurements.setVerbosity(verbosity);
    }

 
    // what the thread instance does
    public void run() {
        
        int no_loop = 0;
        try{
            while (no_loop < nb_outer_iterations) {
                // before computing time tics
                if (records_time_measures)
                    wallclock_times_begin_loops[no_loop] = System.nanoTime();
                
                // computation sample
                this.computeFibs(nb_inner_iterations, nb_stress_class_iterations);
                
                // stressing with your own code.
                // Replace Fibonacci1 by your stressing class name
                // and uncomment the following line to stress with your own code.
                // stress("Fibonacci1", nb_inner_iterations, nb_stress_class_iterations);
                
                // parameterized pause if asked for
                if (pause_time != 0) Thread.sleep((long) pause_time);
                
                // parameterized garbage memory production
                if (this.garbage_producer)
                   produceGarbage(this.nb_inner_iterations, this.nb_stress_class_iterations, this.allocation_array_size);

                // after computation time tics
                if (records_time_measures)
                    wallclock_times_end_loops[no_loop] = System.nanoTime();
                
                no_loop++;
            }
        } catch (InterruptedException ie) {
            System.out.println("java.lang.Thread interrupted");
        }
    }
    
    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        
        // local thread variables
        Thread jlt_bench_thread = null;
        Thread jlt_stress_thread = null;

        int jlt_bench_thread_priority = 0;
        int jlt_stress_thread_priority = 0;

        // local run variables
        boolean jlt_stress_thread_present = false;
        
        // extract program command-line parameters 
           // The bench RT thread parameters (all mandatory)
           int jlt_bench_nb_outer_iterations = new Integer(args[0]).intValue();
           int jlt_bench_nb_inner_iterations = new Integer(args[1]).intValue();
           int jlt_bench_nb_stress_class_iterations = new Integer(args[2]).intValue();
           int jlt_bench_allocation_array_size  = new Integer(args[3]).intValue();
           int jlt_bench_pause_time  = new Integer(args[4]).intValue();
           String jlt_bench_priority_level = args[5];

           // The java.lang.Thread stress thread parameters (all mandatory)
           int jlt_stress_nb_outer_iterations = new Integer(args[6]).intValue();
           int jlt_stress_nb_inner_iterations = new Integer(args[7]).intValue();
           int jlt_stress_nb_stress_class_iterations = new Integer(args[8]).intValue();
           int jlt_stress_allocation_array_size  = new Integer(args[9]).intValue();
           int jlt_stress_pause_time  = new Integer(args[10]).intValue();
           String jlt_stress_priority_level = args[11];

        // Initialization   
        final NonDeterministic bench_nd =
            new NonDeterministic(true, jlt_bench_allocation_array_size, jlt_bench_nb_outer_iterations);
        if ((args.length >= 13) && (args[12].equals("verbose"))) {
            bench_nd.setVerbosity(true);
        }
        else {
            bench_nd.setVerbosity(false);
        }
        final NonDeterministic stress_nd =
            new NonDeterministic(false, jlt_stress_allocation_array_size, jlt_stress_nb_outer_iterations);


        // Bench realtime thread instanciation
        if ((jlt_bench_nb_outer_iterations == 0) || 
            (jlt_bench_nb_inner_iterations == 0) ||
            (jlt_bench_nb_stress_class_iterations == 0)) {
            System.out.println(" Invalid number of iterations specified for bench thread");
            System.exit(1);
        }
        else {
            if (jlt_bench_priority_level.equalsIgnoreCase("max"))
               jlt_bench_thread_priority = Thread.MAX_PRIORITY;
            else if (jlt_bench_priority_level.equalsIgnoreCase("norm"))
               jlt_bench_thread_priority = Thread.NORM_PRIORITY;
            else jlt_bench_thread_priority = Thread.MIN_PRIORITY;

            jlt_bench_thread = new Thread(bench_nd);
            jlt_bench_thread.setPriority(jlt_bench_thread_priority);
        }


        // java.lang.Thread stress thread value checking
        if ((jlt_stress_nb_outer_iterations != 0) &&
            (jlt_stress_nb_inner_iterations != 0) &&
            (jlt_stress_nb_stress_class_iterations != 0)) {

            jlt_stress_thread_present = true;

            if (jlt_stress_priority_level.equalsIgnoreCase("max"))
               jlt_stress_thread_priority = Thread.MAX_PRIORITY;
            else if (jlt_stress_priority_level.equalsIgnoreCase("norm"))
               jlt_stress_thread_priority = Thread.NORM_PRIORITY;
            else jlt_stress_thread_priority = Thread.MIN_PRIORITY;

            jlt_stress_thread = new Thread(stress_nd);
            jlt_stress_thread.setPriority(jlt_stress_thread_priority);
        }
        else {
            jlt_stress_thread_present = false;
        }

        // Iteration data ( captured as program parameters)
        bench_nd.nb_outer_iterations = jlt_bench_nb_outer_iterations;
        bench_nd.nb_inner_iterations = jlt_bench_nb_inner_iterations;
        bench_nd.nb_stress_class_iterations = jlt_bench_nb_stress_class_iterations;
        bench_nd.pause_time = jlt_bench_pause_time;
        bench_nd.thread_priority = jlt_bench_thread_priority;

        stress_nd.nb_outer_iterations = jlt_stress_nb_outer_iterations;
        stress_nd.nb_inner_iterations = jlt_stress_nb_inner_iterations;
        stress_nd.nb_stress_class_iterations = jlt_stress_nb_stress_class_iterations;
        stress_nd.pause_time = jlt_stress_pause_time;
        stress_nd.thread_priority = jlt_stress_thread_priority;

        System.out.println("   Initialization and configuration of program finished.");

        // recap of options 
        System.out.println("\n======================================================================");
        System.out.println("    NonDeterministic program parameters");
        System.out.println("======================================================================");
        System.out.println("   The options used for this run are:   ");
        System.out.println("-------------------------------------\n");
        System.out.println("  java.lang.Thread  bench thread parameters:");
        System.out.println("  ==========================================");
        System.out.println("   Number of outer loops: " + bench_nd.nb_outer_iterations);
        System.out.println("   Number of inner iterations: " + bench_nd.nb_inner_iterations);
        System.out.println("   Number of stress classes iterations: " + bench_nd.nb_stress_class_iterations);
        System.out.println("   Size of elementary array to allocate: " + bench_nd.allocation_array_size);
        System.out.println("   Inner pause time: " + bench_nd.pause_time);
        System.out.println("   Priority level: " + jlt_bench_priority_level);
        System.out.println("   Effective priority assigned: " + bench_nd.thread_priority);
        System.out.println();

        if (jlt_stress_thread_present) {
            System.out.println("  java.lang.Thread stress thread parameters: ");
            System.out.println("  ==========================================");
            System.out.println("   Number of outer loops: " + stress_nd.nb_outer_iterations);
            System.out.println("   Number of inner iterations: " + stress_nd.nb_inner_iterations);
            System.out.println("   Number of stress classes iterations: " + stress_nd.nb_stress_class_iterations);
            System.out.println("   Size of elementary array to allocate: " + stress_nd.allocation_array_size);
            System.out.println("   Inner pause time: " + stress_nd.pause_time);
            System.out.println("   Priority level: " + jlt_stress_priority_level);
            System.out.println("   Effective priority assigned: " + stress_nd.thread_priority);
            System.out.println();
        }
        
        System.out.println("  Output detail level: " + (bench_nd.verbosity?"detailed":"summary"));
        System.out.println("----------------------------------------------------------------------\n");



        // starts time-sharing and/or GC load thread if specified
        System.out.println("\n==================== Starting " + jlt_bench_nb_outer_iterations + " iterations ======================");

        // stabilizes meory and output state before allocating objects
        System.gc();
        System.out.println("Total amount of VM memory : " + Runtime.getRuntime().totalMemory());
        System.gc();
        System.out.println("Amount of free  VM memory : " + Runtime.getRuntime().freeMemory());
        System.gc();
        System.out.println("Max amount of   VM memory : " + Runtime.getRuntime().maxMemory());

        // starts the java.lang.Thread bench thread
        System.out.println(" Starting java.lang.Thread bench thread");
        jlt_bench_thread.start();

        // starts the java.lang.Thread stress thread
        if (jlt_stress_thread_present) {
            System.out.println(" Starting java.lang.Thread stress thread");
            jlt_stress_thread.start();
        }

        try {
            jlt_bench_thread.join();
            System.out.println(" java.lang.Thread bench thread terminated");

            if (jlt_stress_thread_present) {
                jlt_stress_thread.join();
                System.out.println(" java.lang.Thread stress thread terminated");
            }                
            
            System.out.println("==================== Requested " + jlt_bench_nb_outer_iterations + " iterations finished ============== \n");

            System.out.println("\n ==================== Starting output results ===========================");
            bench_nd.outputResults();
            System.out.println(" ==================== Finished results output ============================ \n ");

        }
        catch (InterruptedException ie) {
            System.out.println(ie);
        }
    }
}







